### Name: cir.upndown
### Title: Nonparametric Percentile Estimation for dose-response
###   experiments, using Centered Isotonic Regression (CIR)
### Aliases: cir.upndown
### Keywords: nonparametric survival smooth

### ** Examples


### Up-and-down example from Lacassie and Columb (2003):
### We are estimating the median (ED50) threshold for motor blocking
### potency of levobupivacaine in labor.
### Yes-no table is tallied from their Figure 1.

levo=cbind(c(0,2,2,4,2,1,0,1),c(3,3,5,3,2,1,1,0))

levo

### you should get this table:

###     [,1] [,2]
#[1,]    0    3
#[2,]    2    3
#[3,]    2    5
#[4,]    4    3
#[5,]    2    2
#[6,]    1    1
#[7,]    0    1
#[8,]    1    0

### Note that all doses except the lowest and highest are involved in
### some monotonicity violation (in terms of observed frequency of 'yes' responses)

# The corresponding x values:

levdoses=seq(0.25,0.425,0.025)

### function call
levo.cir.outcome=cir.upndown(yesno=levo,xseq=levdoses,target=0.5,full=TRUE)

### This example is interesting, in that regular isotonic regression
###    would fit y-hat=0.5 for the entire interval between x=0.325 and x=0.4,
###    thereby not providing a unique point estimate for the ED50

### The authors' old-fashioned averaging estimator for ED50 yields
### 0.31 as the point estimate, and a probit regression (as reported in the article) 
### places it at 0.37

### The CIR point estimate (below) is around 0.345, almost exactly in the
### middle between these two

levo.cir.outcome$out

### The authors' 95% confidence interval estimate is amazingly optimistic
### at (0.29,0.34). CIR's estimate is more conservative
### because it indirectly accounts for the gross monotonicity violations in the data
### It is more in line with the probit-regression estimate of (0.30,0.45)

levo.cir.outcome$ci




